import { FastifyBaseLogger } from 'fastify';
import { CircleOIDCPlatform, InvalidOIDCPlatform, OIDCSecretExchangeConfig, OIDCSecretExchangeConfigItem, OIDCSecretExchangeConfiguration } from '../config';
import { BaseClaims, CircleCIOIDCClaims } from '../type';
export type SubjectedSecretProvider = {
    subject: string;
    providers: OIDCSecretExchangeConfiguration<object, unknown>['provider'][];
};
export type PlatformHandler<TConfig extends OIDCSecretExchangeConfig[0], TClaims extends BaseClaims> = {
    discoveryUrlForToken: (config: TConfig, token: string) => string | null;
    validateToken: (token: string, discoveryUrl: string) => Promise<TClaims | null>;
    filterSecretProviders: (config: TConfig, claims: TClaims) => Promise<SubjectedSecretProvider>;
};
export declare const perPlatformHandlers: {
    circleci: PlatformHandler<OIDCSecretExchangeConfigItem<CircleOIDCPlatform>, CircleCIOIDCClaims>;
    invalid: PlatformHandler<OIDCSecretExchangeConfigItem<InvalidOIDCPlatform>, BaseClaims>;
};
export declare const getProvidersForConfig: <TClaims extends BaseClaims, TConfig extends OIDCSecretExchangeConfigItem<CircleOIDCPlatform> | OIDCSecretExchangeConfigItem<InvalidOIDCPlatform>, THandler extends PlatformHandler<TConfig, TClaims>>(logger: FastifyBaseLogger, config: TConfig, handler: THandler & PlatformHandler<TConfig, TClaims>, token: string) => Promise<SubjectedSecretProvider | null>;
